@@ -11,16 +11,20 @@
 # under the License.
 
 import json
+import time
 
 import requests
 
 from functionaltests.api import base
+from functionaltests.api.common import apputils
 
 
 class TestTriggerController(base.TestCase):
 
     def test_trigger_post(self):
-        resp = self.client.create_app()
+        lp_name = self.client.create_lp()
+        data = apputils.get_sample_data(languagepack=lp_name)
+        resp = self.client.create_app(data=data)
         bdy = json.loads(resp.body)
         trigger_uri = bdy['trigger_uri']
         # Using requests instead of self.client to test unauthenticated request
@@ -30,12 +34,26 @@ class TestTriggerController(base.TestCase):
                      'repository': {'statuses_url': status_url}}
         body = json.dumps(body_dict)
         resp = requests.post(trigger_uri, data=body)
-        self.assertEqual(resp.status_code, 202)
+        self.assertEqual(202, resp.status_code)
+        self.client.delete_created_apps()
+        # since app delete is an async operation, wait few seconds for app
+        # delete and then delete language pack (otherwise language pack
+        # cannot be deleted)
+        time.sleep(2)
+        self.client.delete_created_lps()
 
     def test_trigger_post_with_empty_body(self):
-        resp = self.client.create_app()
+        lp_name = self.client.create_lp()
+        data = apputils.get_sample_data(languagepack=lp_name)
+        resp = self.client.create_app(data=data)
         bdy = json.loads(resp.body)
         trigger_uri = bdy['trigger_uri']
         # Using requests instead of self.client to test unauthenticated request
         resp = requests.post(trigger_uri)
-        self.assertEqual(resp.status_code, 400)
+        self.assertEqual(400, resp.status_code)
+        self.client.delete_created_apps()
+        # since app delete is an async operation, wait few seconds for app
+        # delete and then delete language pack (otherwise language pack
+        # cannot be deleted)
+        time.sleep(2)
+        self.client.delete_created_lps()
